#!/usr/bin/python3
import psutil
import os
import time
from datetime import datetime
from configparser import ConfigParser
import requests
import json


def get_netcard():
    try:
        """获取网卡名称和ip地址"""
        netcard_info = []
        info = psutil.net_if_addrs()
        for k, v in info.items():
            for item in v:
                if item[0] == 2 and not item[1] == '127.0.0.1':
                    netcard_info.append(item[1])
        # netcard_info.append("192.168.26.71")
        return netcard_info
    except Exception as e:
        return []


def geturl():
    try:
        conf = ConfigParser()
        conf.read('/etc/sysmonitor/site.conf')
        host = str(conf['site']['host'])
        port = str(conf['site']['port'])
        if host != "" and port != "":
            return host+":"+port
        else:
            return ""
    except Exception as e:
        return ""


def getuuid():
    ips = get_netcard()
    if len(ips) < 1:
        return ""
    path = geturl()
    if path == "":
        return ""
    url = "http://"+path+"/uuids"
    querystring = {"ips": ",".join(ips)}
    try:
        response = requests.request("GET", url, params=querystring)
        obj = json.loads(response.text)
        if len(obj) > 0:
            return obj[0]["uuid"]
        else:
            return ""
    except Exception as e:
        return ""


def sendMessage(path, uuid, type, message):
    if path == "" or uuid == "":
        return ""
    url = "http://"+path+"/v1/simple_alerts"
    payload = {
        "alertName": "使用率",
        "alertType": type,
        "level": "p4",
        "status": "firing",
        "hostUuid": uuid,
        "description": message
    }
    try:
        requests.request("POST", url, json=payload)
    except Exception as e:
        return ""


conf = ConfigParser()
conf.read('/etc/sysmonitor/device.conf')
try:
    maxmem = float(conf['memory']['max_percent'])
    maxcpu = float(conf['cpu']['max_percent'])
    sleeptime = int(conf['system']['sleeptime'])
except Exception as e:
    print("no files in /etc/sysmonitor/device.conf")
    exit(-1)

tmptime = datetime.now()
uuid = getuuid()
path = geturl()

while True:

    info = psutil.virtual_memory()
    nowmem = info.percent
    nowcpu = psutil.cpu_percent()
    nowtime = datetime.now()
    dt_ms = nowtime.strftime('%Y-%m-%d %H:%M:%S.%f')
    if nowmem > maxmem:
        infostr = "["+dt_ms+"] memory-percent:"+str(nowmem)
        # difftime = (nowtime-tmptime).seconds
        sendMessage(path, uuid, "memory", infostr)
        os.system('echo '+infostr+" >> /var/log/sysmonitor.log")
        os.system('notify-send "'+infostr+'"')
        os.system('wall "'+infostr+'"')
        
    if nowcpu > maxcpu:
        infostr = "["+dt_ms+"] cpu-percent:"+str(nowcpu)
        sendMessage(path, uuid, "cpu", infostr)
        # difftime = (nowtime-tmptime).seconds
        os.system('echo '+infostr+" >> /var/log/sysmonitor.log")
        os.system('notify-send "'+infostr+'"')
        os.system('wall "'+infostr+'"')
        # print(infostr)
    time.sleep(sleeptime)
